/**
 * GraphQL Query that fetches the list of products with details using sort,
 * filters and pagination.
 */
declare const _default: "\n  query productDetails(\n    $search: String = \"\",\n    $filter: ProductAttributeFilterInput,\n    $pageSize: Int = 10,\n    $currentPage: Int = 1,\n    $sort: ProductAttributeSortInput\n  ) {\n    products(search: $search, filter: $filter, sort: $sort, pageSize: $pageSize, currentPage: $currentPage) {\n      items {\n        uid\n        sku\n        name\n        thumbnail {\n          url\n          position\n          disabled\n          label\n        }\n        url_key\n        url_rewrites {\n          url\n        }\n        categories {\n          uid\n          name\n          url_suffix\n          url_path\n          breadcrumbs {\n            category_name,\n            category_url_path\n          }\n        }\n        rating_summary\n        review_count\n        reviews {\n          items {\n            average_rating\n            ratings_breakdown {\n              name\n              value\n            }\n          }\n        }\n        small_image {\n          url\n          position\n          disabled\n          label\n        }\n        image {\n          url\n          position\n          disabled\n          label\n        }\n        media_gallery {\n          url\n          position\n          disabled\n          label\n        }\n        thumbnail {\n          url\n          position\n          disabled\n          label\n        }\n        url_key\n        url_rewrites {\n          url\n        }\n        meta_description\n        meta_keyword\n        meta_title\n        description {\n          html\n        }\n        short_description {\n          html\n        }\n        options_container\n        special_to_date\n        ... on ConfigurableProduct {\n          configurable_options {\n            attribute_code\n            attribute_uid\n            label\n            position\n            uid\n            use_default\n            values {\n              label\n              swatch_data {\n                value\n              }\n              uid\n            }\n          }\n        }\n\n        ... on DownloadableProduct {\n          downloadable_product_samples {\n            sample_url\n            title\n          }\n          downloadable_product_links {\n            id\n            price\n            title\n            uid\n          }\n        }\n        ... on VirtualProduct {\n          gift_message_available\n          product_links {\n            link_type\n            linked_product_sku\n            linked_product_type\n            position\n            sku\n          }\n        }\n        ... on GroupedProduct {\n          items {\n            position\n            qty\n            product {\n              uid\n              sku\n              name\n              stock_status\n              only_x_left_in_stock\n              price_range {\n                maximum_price {\n                  final_price {\n                    currency\n                    value\n                  }\n                  regular_price {\n                    currency\n                    value\n                  }\n                }\n                minimum_price {\n                  final_price {\n                    currency\n                    value\n                  }\n                  regular_price {\n                    currency\n                    value\n                  }\n                }\n              }\n              thumbnail {\n                url\n                position\n                disabled\n                label\n              }\n            }\n          }\n        }\n      }\n    }\n  }\n";
export default _default;
//# sourceMappingURL=productDetailsQuery.d.ts.map